@@ -17,5 +17,7 @@
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 utils::globalVariables( c('dist',
+                          'from',
+                          'to',
                           'a') )
 
